% SBS simulation - main program. 
% Written by Asaf David, Department of Electrical Engineering, Technion, Haifa, Isreal, 2011.
% Steady state equations are solved in the function 'Steady_state_solution' (equations 11 in R. B. Jenkins, R. M. Sova, and R. I. Joseph, Steady-State Noise Analysis of Spontaneous and Stimulated Brillouin
% Scattering in Optical Fibers, IEEE J. Lightwave Technol. 25, 763770 (2007))
% Dynamic equations are solved in the function 'Dynamic_solution' (equations (1a)-(1c) in the article)
% RF preiodogram of the reflected and the transmiotted signal is calculated in the function 'RF_spec' (equation 2 in the article)

close all;  clear all;  clc;
tic
globalize_vars;
L=25e3; %[m] Fiber length
P0=15e-3; %[W] Input power
iterations=4e6; %number of iterations for the calculation of the dynamics 
%% general constants
n=1.447; %Index of refraction
eps0=8.854e-12; % [F/m] Vacuum permittivity
c=2.9979e8; % [m/sec] Speed of light
Z0=377;   %[Ohm] Vacuum impedance
dz=1; dt=dz*n/c;    %Spacial and Temporal step sizes.
N=L/dz; % Fiber length discretization
z=0:dz:(dz*N-dz); 
%% material characteristics
lambdaL=1.55e-6;            % [m] pump wavelength
WL=2*pi*c/lambdaL;       %[Hz]  pump frequency
g0=1.12e-11;    % [m^2/W] gain coefficient
GAMMAb=30e6*2*pi; %[1/t] phonons decay rate
A=80e-12;   %[m] fiber's effective area
Omega=10.86e9;  %[Hz] acoustic frequency
gammaE=0.8967;  %electrostrictive coefficient
Va=5960;    %[m/s] Velocity of sound
LAMBDA=gammaE*Omega/c/Z0/2/Va^2;    %Brillouin coupling parameter - acoustic equation
kappa=g0*GAMMAb*n/2/Z0/LAMBDA;  %Brillouin coupling parameter - optic equations
kT=293*1.3806504e-23;       %[Joule]        at room temprature. 
roh0=2210;       % [kg/m^3]  mean density for SiO2, bulk (http://www.virginiasemi.com/pdf/generalpropertiesSi62002.pdf) . 
Q=2*kT*roh0*GAMMAb/(Va^2*A);     %Noise std.

I1_0=P0/A;  %[W/m^2] Pump intensity
Alpha=0.25;            %[dB/km]    losses 
 if (Alpha==0)
     Leff=L;        %  For No Losses Model
 else                   % For Lossy Fiber
    Alpha=Alpha/4.343*1e-3;                  %[1/m],                     losses 
    Leff=(1-exp(-Alpha*L))/Alpha;   %[m] effective length
 end;
% Coefficients
G=g0*I1_0*Leff;                         %Gain factor
B=sqrt(g0*4*kT*WL*GAMMAb/A/L/Omega);    %Noise term coupling for steady state solution
Gth=21; %Agrawal, pp.361

%% Numerical and Analytical Solutions

% Approximated steady state solution 
[Is,Il]=Steady_state_solution(P0,z,dz,g0,B,Alpha,A);

% Figure 1 - Steady state longitudinal intensity profile
figure
plot(z,Il,z,Is,'g')
xlabel('z [m]'); ylabel('Intensity [W/m^2]');
title('steady state approximated profile');
legend('Incoming wave','Stokes wave');
El=sqrt(Il*Z0/2/n); %[V/m] Pump Field, Steady State
Es=sqrt(Is*Z0/2/n); %[V/m] Stokes Field, Steady State

%Dynamic solution - first transient iterations 
figure;
roh=zeros(1,N);
ten_RT_iter=L*dz*20; %corresponds to 10 * roundtrip time
[ES0_T,EL_L_T,EL,ES,roh]=Dynamic_solution(L,Es,El,Es,El,dz,dt,z,N,Q,ten_RT_iter,roh,A,0);
%Already stationaric. This calculation gives the final results.
[ES0_T,EL_L_T,EL,ES,roh]=Dynamic_solution(L,ES,EL,Es,El,dz,dt,z,N,Q,iterations,roh,A,1);

Sim_Time=toc;

%% Graphic Results
T=dt:dt:dt*iterations;
fs=1/dt;

save('SBS_results','G','L','P0','Alpha','T','ES0_T','EL_L_T','dz','dt','Sim_Time','fs');

% Figure 3 - Temporal Intensity Behavior
figure
plot(T*1e3,2*n/Z0*abs(ES0_T).^2);
title('Intensities fluctuations in time')
hold all;
xlabel('Time[ms]'); ylabel('Intesity [W/m^2]')
plot(T*1e3,2*n/Z0*abs(EL_L_T).^2);
legend('Stokes','Pump')

% Figure 4 - Comparisson to steady state solution
 figure
 subplot(2,1,1);    plot(z,Il,z,2*n/Z0*abs(EL).^2,'r')
 xlabel('z [m]'); ylabel('Intensity [W/m^2]');
 title('I_L (Pump)')
legend('Numerical Steady State', 'Numercial Dynamic')
 subplot(2,1,2);    plot(z,Is,z,2*n/Z0*abs(ES).^2,'r')
 xlabel('z [m]'); ylabel('Intensity [W/m^2]');
 title('I_S (Stokes)')
legend('Numerical Steady State', 'Numercial Dynamic')


% figure 5 and 6 - Transferred and Reflected periodograms
figure;
RF_spec (Z0,n,A,dt,EL_L_T,T,1e6,P0,L,20,1)
figure;
RF_spec (Z0,n,A,dt,ES0_T,T,1e7,P0,L,20,0)
